Learn R Programming

twenty48 (version 0.2.1)

twenty48-package: twenty48: Play a Game of 2048 in the Console

Description

logo

Generates a game of 2048 that can be played in the console. Supports grids of arbitrary sizes, undoing the last move, and resuming a game that was exited during the current session.

Arguments

Author

Maintainer: Alexander Rossell Hayes alexander@rossellhayes.com (ORCID) [copyright holder]

See Also